netapp_ontap.models.cluster_peer_status API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cluster_peer_status`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ClusterPeerStatusSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterPeerStatus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `state GET`

    The state field of the cluster_peer_status.

    Valid choices:

    - available
    - partial
    - unavailable
    - pending
    - unidentified
  `update_time GET`

    The last time the state was updated.

    Example: 2017-01-25T11:20:13.000+0000